.. contents::

Overview
========

.. role:: mod(emphasis)

:mod:`utyls` is a Python library that provides a few useful common utilities

Requirements:

- Python 2.5 - 2.7

Licence
-------

Made available as-is under the BSD Licence.
